@@ -1,5 +1,6 @@
 from dataclasses import dataclass, field
 
+from mobt.GitCli.GitPython import log_undoing_all_git_commands
 from mobt.GitCli.UndoCommands.UndoCommand import UndoCommand
 
 
@@ -8,6 +9,11 @@ class ComposedUndoCommand(UndoCommand):
     __commands: list[UndoCommand] = field(default_factory=list)
 
     def undo(self):
+        if not self.has_commands:
+            return
+
+        log_undoing_all_git_commands()
+
         for command in reversed(self.__commands):
             command.undo()
 
